searchNodes=[{"ref":"Mix.Tasks.Sentry.SendTestEvent.html","title":"Mix.Tasks.Sentry.SendTestEvent","type":"task","doc":"Send test even to check if Sentry configuration is correct."},{"ref":"Mix.Tasks.Sentry.SendTestEvent.html#run/1","title":"Mix.Tasks.Sentry.SendTestEvent.run/1","type":"function","doc":"A task needs to implement run which receives a list of command line args. Callback implementation for Mix.Task.run/1."},{"ref":"Sentry.html","title":"Sentry","type":"module","doc":"Provides the basic functionality to submit a Sentry.Event to the Sentry Service. Configuration Add the following to your production config config :sentry, dsn: &quot;https://public:secret@app.getsentry.com/1&quot;, included_environments: [:prod], environment_name: :prod, tags: %{ env: &quot;production&quot; } The environment_name and included_environments work together to determine if and when Sentry should record exceptions. The environment_name is the name of the current environment. In the example above, we have explicitly set the environment to :prod which works well if you are inside an environment specific configuration config/prod.exs. An alternative is to use Mix.env in your general configuration file: config :sentry, dsn: &quot;https://public:secret@app.getsentry.com/1&quot;, included_environments: [:prod], environment_name: Mix.env This will set the environment name to whatever the current Mix environment atom is, but it will only send events if the current environment is :prod, since that is the only entry in the included_environments key. You can even rely on more custom determinations of the environment name. It&#39;s not uncommmon for most applications to have a &quot;staging&quot; environment. In order to handle this without adding an additional Mix environment, you can set an environment variable that determines the release level. config :sentry, dsn: &quot;https://public:secret@app.getsentry.com/1&quot;, included_environments: ~w(production staging), environment_name: System.get_env(&quot;RELEASE_LEVEL&quot;) || &quot;development&quot; In this example, we are getting the environment name from the RELEASE_LEVEL environment variable. If that variable does not exist, we default to &quot;development&quot;. Now, on our servers, we can set the environment variable appropriately. On our local development machines, exceptions will never be sent, because the default value is not in the list of included_environments. Filtering Exceptions If you would like to prevent certain exceptions, the :filter configuration option allows you to implement the Sentry.EventFilter behaviour. The first argument is the exception to be sent, and the second is the source of the event. Sentry.Plug will have a source of :plug, Sentry.LoggerBackend will have a source of :logger, and Sentry.Phoenix.Endpoint will have a source of :endpoint. If an exception does not come from either of those sources, the source will be nil unless the :event_source option is passed to Sentry.capture_exception/2 A configuration like below will prevent sending Phoenix.Router.NoRouteError from Sentry.Plug, but allows other exceptions to be sent. # sentry_event_filter.ex defmodule MyApp.SentryEventFilter do @behaviour Sentry.EventFilter def exclude_exception?(%Elixir.Phoenix.Router.NoRouteError{}, :plug), do: true def exclude_exception?(_exception, _source), do: false end # config.exs config :sentry, filter: MyApp.SentryEventFilter, included_environments: ~w(production staging), environment_name: System.get_env(&quot;RELEASE_LEVEL&quot;) || &quot;development&quot; Capturing Exceptions Simply calling capture_exception/2 will send the event. By default, the event is sent asynchronously and the result can be awaited upon. The :result option can be used to change this behavior. See Sentry.Client.send_event/2 for more information. {:ok, task} = Sentry.capture_exception(my_exception) {:ok, event_id} = Task.await(task) {:ok, another_event_id} = Sentry.capture_exception(other_exception, [event_source: :my_source, result: :sync]) Options :event_source - The source passed as the first argument to Sentry.EventFilter.exclude_exception?/2 Configuring The Logger Backend See Sentry.LoggerBackend"},{"ref":"Sentry.html#capture_exception/2","title":"Sentry.capture_exception/2","type":"function","doc":"Parses and submits an exception to Sentry if current environment is in included_environments. opts argument is passed as the second argument to Sentry.send_event/2."},{"ref":"Sentry.html#capture_message/2","title":"Sentry.capture_message/2","type":"function","doc":"Reports a message to Sentry. opts argument is passed as the second argument to Sentry.send_event/2."},{"ref":"Sentry.html#send_event/2","title":"Sentry.send_event/2","type":"function","doc":"Sends a Sentry.Event opts argument is passed as the second argument to send_event/2 of the configured Sentry.HTTPClient. See Sentry.Client.send_event/2 for more information."},{"ref":"Sentry.html#start/2","title":"Sentry.start/2","type":"function","doc":"Called when an application is started. This function is called when an application is started using Application.start/2 (and functions on top of that, such as Application.ensure_started/2). This function should start the top-level process of the application (which should be the top supervisor of the application&#39;s supervision tree if the application follows the OTP design principles around supervision). start_type defines how the application is started: :normal - used if the startup is a normal startup or if the application is distributed and is started on the current node because of a failover from another node and the application specification key :start_phases is :undefined. {:takeover, node} - used if the application is distributed and is started on the current node because of a failover on the node node. {:failover, node} - used if the application is distributed and is started on the current node because of a failover on node node, and the application specification key :start_phases is not :undefined. start_args are the arguments passed to the application in the :mod specification key (e.g., mod: {MyApp, [:my_args]}). This function should either return {:ok, pid} or {:ok, pid, state} if startup is successful. pid should be the PID of the top supervisor. state can be an arbitrary term, and if omitted will default to []; if the application is later stopped, state is passed to the stop/1 callback (see the documentation for the c:stop/1 callback for more information). use Application provides no default implementation for the start/2 callback. Callback implementation for Application.start/2."},{"ref":"Sentry.html#t:send_result/0","title":"Sentry.send_result/0","type":"type","doc":""},{"ref":"Sentry.Client.html","title":"Sentry.Client","type":"module","doc":"This module is the default client for sending an event to Sentry via HTTP. It makes use of Task.Supervisor to allow sending tasks synchronously or asynchronously, and defaulting to asynchronous. See Sentry.Client.send_event/2 for more information. Configuration :before_send_event - allows performing operations on the event before it is sent. Accepts an anonymous function or a {module, function} tuple, and the event will be passed as the only argument. :after_send_event - callback that is called after attempting to send an event. Accepts an anonymous function or a {module, function} tuple. The result of the HTTP call as well as the event will be passed as arguments. The return value of the callback is not returned. Example configuration of putting Logger metadata in the extra context: config :sentry, before_send_event: fn(event) -&gt; metadata = Map.new(Logger.metadata) %{event | extra: Map.merge(event.extra, metadata)} end, after_send_event: fn(event, result) -&gt; case result do {:ok, id} -&gt; Logger.info(&quot;Successfully sent event!&quot;) _ -&gt; Logger.info(fn -&gt; &quot;Did not successfully send event! \#{inspect(event)}&quot; end) end end"},{"ref":"Sentry.Client.html#authorization_header/2","title":"Sentry.Client.authorization_header/2","type":"function","doc":"Generates a Sentry API authorization header."},{"ref":"Sentry.Client.html#get_dsn/0","title":"Sentry.Client.get_dsn/0","type":"function","doc":"Get a Sentry DSN which is simply a URI. {PROTOCOL}://{PUBLIC_KEY}[:{SECRET_KEY}]@{HOST}/{PATH}{PROJECT_ID}"},{"ref":"Sentry.Client.html#hackney_pool_name/0","title":"Sentry.Client.hackney_pool_name/0","type":"function","doc":""},{"ref":"Sentry.Client.html#maybe_call_after_send_event/2","title":"Sentry.Client.maybe_call_after_send_event/2","type":"function","doc":""},{"ref":"Sentry.Client.html#maybe_call_before_send_event/1","title":"Sentry.Client.maybe_call_before_send_event/1","type":"function","doc":""},{"ref":"Sentry.Client.html#render_event/1","title":"Sentry.Client.render_event/1","type":"function","doc":"Transform the Event struct into JSON map. Most Event attributes map directly to JSON map, with stacktrace being the exception. If the event does not have stacktrace frames, it should not be included in the JSON body."},{"ref":"Sentry.Client.html#request/3","title":"Sentry.Client.request/3","type":"function","doc":"Makes the HTTP request to Sentry using hackney. Hackney options can be set via the hackney_opts configuration option."},{"ref":"Sentry.Client.html#send_event/2","title":"Sentry.Client.send_event/2","type":"function","doc":"Attempts to send the event to the Sentry API up to 4 times with exponential backoff. The event is dropped if it all retries fail. Options :result - Allows specifying how the result should be returned. Options include :sync, :none, and :async. :sync will make the API call synchronously, and return {:ok, event_id} if successful. :none sends the event from an unlinked child process under Sentry.TaskSupervisor and will return {:ok, &quot;&quot;} regardless of the result. :async will start an unlinked task and return a tuple of {:ok, Task.t} on success where the Task can be awaited upon to receive the result asynchronously. When used in an OTP behaviour like GenServer, the task will send a message that needs to be matched with GenServer.handle_info/2. See Task.Supervisor.async_nolink/2 for more information. :async is the default. :sample_rate - The sampling factor to apply to events. A value of 0.0 will deny sending any events, and a value of 1.0 will send 100% of events."},{"ref":"Sentry.Client.html#t:dsn/0","title":"Sentry.Client.dsn/0","type":"type","doc":""},{"ref":"Sentry.Client.html#t:result/0","title":"Sentry.Client.result/0","type":"type","doc":""},{"ref":"Sentry.Client.html#t:send_event_result/0","title":"Sentry.Client.send_event_result/0","type":"type","doc":""},{"ref":"Sentry.Config.html","title":"Sentry.Config","type":"module","doc":"This module provides the functionality for fetching configuration settings and their defaults. Sentry supports loading config at runtime, via {:system, &quot;SYSTEM_ENV_KEY&quot;} tuples, where Sentry will read SYSTEM_ENV_KEY to get the config value from the system environment at runtime."},{"ref":"Sentry.Config.html#after_send_event/0","title":"Sentry.Config.after_send_event/0","type":"function","doc":""},{"ref":"Sentry.Config.html#before_send_event/0","title":"Sentry.Config.before_send_event/0","type":"function","doc":""},{"ref":"Sentry.Config.html#client/0","title":"Sentry.Config.client/0","type":"function","doc":""},{"ref":"Sentry.Config.html#context_lines/0","title":"Sentry.Config.context_lines/0","type":"function","doc":""},{"ref":"Sentry.Config.html#dsn/0","title":"Sentry.Config.dsn/0","type":"function","doc":""},{"ref":"Sentry.Config.html#enable_source_code_context/0","title":"Sentry.Config.enable_source_code_context/0","type":"function","doc":""},{"ref":"Sentry.Config.html#environment_name/0","title":"Sentry.Config.environment_name/0","type":"function","doc":""},{"ref":"Sentry.Config.html#filter/0","title":"Sentry.Config.filter/0","type":"function","doc":""},{"ref":"Sentry.Config.html#hackney_opts/0","title":"Sentry.Config.hackney_opts/0","type":"function","doc":""},{"ref":"Sentry.Config.html#hackney_timeout/0","title":"Sentry.Config.hackney_timeout/0","type":"function","doc":""},{"ref":"Sentry.Config.html#in_app_module_whitelist/0","title":"Sentry.Config.in_app_module_whitelist/0","type":"function","doc":""},{"ref":"Sentry.Config.html#included_environments/0","title":"Sentry.Config.included_environments/0","type":"function","doc":"The :included_environments config key expects a list, but if given a string, it will split the string on commas to create a list."},{"ref":"Sentry.Config.html#json_library/0","title":"Sentry.Config.json_library/0","type":"function","doc":""},{"ref":"Sentry.Config.html#log_level/0","title":"Sentry.Config.log_level/0","type":"function","doc":""},{"ref":"Sentry.Config.html#max_hackney_connections/0","title":"Sentry.Config.max_hackney_connections/0","type":"function","doc":""},{"ref":"Sentry.Config.html#permitted_log_level_values/0","title":"Sentry.Config.permitted_log_level_values/0","type":"function","doc":""},{"ref":"Sentry.Config.html#release/0","title":"Sentry.Config.release/0","type":"function","doc":""},{"ref":"Sentry.Config.html#report_deps/0","title":"Sentry.Config.report_deps/0","type":"function","doc":""},{"ref":"Sentry.Config.html#root_source_code_path/0","title":"Sentry.Config.root_source_code_path/0","type":"function","doc":""},{"ref":"Sentry.Config.html#sample_rate/0","title":"Sentry.Config.sample_rate/0","type":"function","doc":""},{"ref":"Sentry.Config.html#server_name/0","title":"Sentry.Config.server_name/0","type":"function","doc":""},{"ref":"Sentry.Config.html#source_code_exclude_patterns/0","title":"Sentry.Config.source_code_exclude_patterns/0","type":"function","doc":""},{"ref":"Sentry.Config.html#source_code_path_pattern/0","title":"Sentry.Config.source_code_path_pattern/0","type":"function","doc":""},{"ref":"Sentry.Config.html#tags/0","title":"Sentry.Config.tags/0","type":"function","doc":""},{"ref":"Sentry.Config.html#validate_config!/0","title":"Sentry.Config.validate_config!/0","type":"function","doc":""},{"ref":"Sentry.Context.html","title":"Sentry.Context","type":"module","doc":"Provides functionality to store user, tags, extra, and breadcrumbs context when an event is reported. The contexts will be fetched and merged into the event when it is sent. When calling Sentry.Context, the Process Dictionary is used to store this state. This imposes some limitations. The state will only exist within the current process, and the context will die with the process. For example, if you add context inside your controller and an error happens in a Task, that context will not be included. A common use-case is to set context within Plug or Phoenix applications, as each request is its own process, and so any stored context will be included should an error be reported within that request process. Example: # post_controller.ex def index(conn, _params) do Sentry.Context.set_user_context(%{id: conn.assigns.user_id}) posts = Blog.list_posts() render(conn, &quot;index.html&quot;, posts: posts) end It should be noted that the set_*_context/1 functions merge with the existing context rather than entirely overwriting it."},{"ref":"Sentry.Context.html#add_breadcrumb/1","title":"Sentry.Context.add_breadcrumb/1","type":"function","doc":"Adds a new breadcrumb to the :breadcrumb context, specific to the current process. Breadcrumbs are used to record a series of events that led to a specific instance of an error. Breadcrumbs can contain arbitrary key data to assist in understanding what happened before an error occurred. Example iex&gt; Sentry.Context.add_breadcrumb(message: &quot;first_event&quot;) nil iex&gt; Sentry.Context.add_breadcrumb(%{message: &quot;second_event&quot;, type: &quot;auth&quot;}) %{breadcrumbs: [%{:message =&gt; &quot;first_event&quot;, &quot;timestamp&quot; =&gt; 1562007480}]} iex&gt; Sentry.Context.add_breadcrumb(%{message: &quot;response&quot;}) %{ breadcrumbs: [ %{:message =&gt; &quot;second_event&quot;, :type =&gt; &quot;auth&quot;, &quot;timestamp&quot; =&gt; 1562007505}, %{:message =&gt; &quot;first_event&quot;, &quot;timestamp&quot; =&gt; 1562007480} ] } iex&gt; Sentry.Context.get_all() %{ breadcrumbs: [ %{:message =&gt; &quot;first_event&quot;, &quot;timestamp&quot; =&gt; 1562007480}, %{:message =&gt; &quot;second_event&quot;, :type =&gt; &quot;auth&quot;, &quot;timestamp&quot; =&gt; 1562007505}, %{:message =&gt; &quot;response&quot;, &quot;timestamp&quot; =&gt; 1562007517} ], extra: %{}, request: %{}, tags: %{}, user: %{} }"},{"ref":"Sentry.Context.html#clear_all/0","title":"Sentry.Context.clear_all/0","type":"function","doc":"Clears all existing context for the current process. Example iex&gt; Sentry.Context.set_tags_context(%{id: 123}) nil iex&gt; Sentry.Context.clear_all() %{tags: %{id: 123}} iex&gt; Sentry.Context.get_all() %{breadcrumbs: [], extra: %{}, request: %{}, tags: %{}, user: %{}}"},{"ref":"Sentry.Context.html#context_keys/0","title":"Sentry.Context.context_keys/0","type":"function","doc":"Returns the keys used to store context in the current Process&#39;s process dictionary. Example iex&gt; Sentry.Context.context_keys() [:breadcrumbs, :tags, :user, :extra]"},{"ref":"Sentry.Context.html#get_all/0","title":"Sentry.Context.get_all/0","type":"function","doc":"Retrieves all currently set context on the current process. Example iex&gt; Sentry.Context.set_user_context(%{id: 123}) iex&gt; Sentry.Context.set_tags_context(%{message_id: 456}) iex&gt; Sentry.Context.get_all() %{ user: %{id: 123}, tags: %{message_id: 456}, extra: %{}, request: %{}, breadcrumbs: [] }"},{"ref":"Sentry.Context.html#set_extra_context/1","title":"Sentry.Context.set_extra_context/1","type":"function","doc":"Merges new fields into the :extra context, specific to the current process. This is used to set fields which should display when looking at a specific instance of an error. Example iex&gt; Sentry.Context.set_extra_context(%{id: 123}) nil iex&gt; Sentry.Context.set_extra_context(%{detail: &quot;bad_error&quot;}) %{extra: %{id: 123}} iex&gt; Sentry.Context.set_extra_context(%{message: &quot;Oh no&quot;}) %{extra: %{detail: &quot;bad_error&quot;, id: 123}} iex&gt; Sentry.Context.get_all() %{ user: %{}, tags: %{}, extra: %{detail: &quot;bad_error&quot;, id: 123, message: &quot;Oh no&quot;}, request: %{}, breadcrumbs: [] }"},{"ref":"Sentry.Context.html#set_http_context/1","title":"Sentry.Context.set_http_context/1","type":"function","doc":"Merges new fields into the :request context, specific to the current process. This is used to set metadata that identifies the request associated with a specific instance of an error. Example iex(1)&gt; Sentry.Context.set_http_context(%{id: 123}) nil iex(2)&gt; Sentry.Context.set_http_context(%{url: &quot;www.example.com&quot;}) %{request: %{id: 123}} iex(3)&gt; Sentry.Context.get_all() %{ breadcrumbs: [], extra: %{}, request: %{id: 123, url: &quot;www.example.com&quot;}, tags: %{}, user: %{} }"},{"ref":"Sentry.Context.html#set_tags_context/1","title":"Sentry.Context.set_tags_context/1","type":"function","doc":"Merges new fields into the :tags context, specific to the current process. This is used to set fields which should display when looking at a specific instance of an error. These fields can also be used to search and filter on. Example iex&gt; Sentry.Context.set_tags_context(%{id: 123}) nil iex&gt; Sentry.Context.set_tags_context(%{other_id: 456}) %{tags: %{id: 123}} iex&gt; Sentry.Context.get_all() %{ breadcrumbs: [], extra: %{}, request: %{}, tags: %{id: 123, other_id: 456}, user: %{} }"},{"ref":"Sentry.Context.html#set_user_context/1","title":"Sentry.Context.set_user_context/1","type":"function","doc":"Merges new fields into the :user context, specific to the current process. This is used to set certain fields which identify the actor who experienced a specific instance of an error. Example iex&gt; Sentry.Context.set_user_context(%{id: 123}) nil iex&gt; Sentry.Context.set_user_context(%{username: &quot;george&quot;}) %{user: %{id: 123}} iex&gt; Sentry.Context.get_all() %{ user: %{id: 123, username: &quot;george&quot;}, tags: %{}, extra: %{}, request: %{}, breadcrumbs: [] }"},{"ref":"Sentry.Event.html","title":"Sentry.Event","type":"module","doc":"Provides an Event Struct as well as transformation of Logger entries into Sentry Events. Configuration :in_app_module_whitelist - Expects a list of modules that is used to distinguish among stacktrace frames that belong to your app and ones that are part of libraries or core Elixir. This is used to better display the significant part of stacktraces. The logic is greedy, so if your app&#39;s root module is MyApp and your setting is [MyApp], that module as well as any submodules like MyApp.Submodule would be considered part of your app. Defaults to []. :report_deps - Flag for whether to include the loaded dependencies when reporting an error. Defaults to true."},{"ref":"Sentry.Event.html#add_metadata/1","title":"Sentry.Event.add_metadata/1","type":"function","doc":""},{"ref":"Sentry.Event.html#args_from_stacktrace/1","title":"Sentry.Event.args_from_stacktrace/1","type":"function","doc":"Builds a map from argument value list. For Sentry, typically the key in the map would be the name of the variable, but we don&#39;t have that available."},{"ref":"Sentry.Event.html#create_event/1","title":"Sentry.Event.create_event/1","type":"function","doc":"Creates an Event struct out of context collected and options Options :exception - Sentry-formatted exception :original_exception - Original exception :message - message :stacktrace - a list of Exception.stacktrace() :extra - map of extra context :user - map of user context :tags - map of tags context :request - map of request context :breadcrumbs - list of breadcrumbs :event_source - the source of the event :level - error level :fingerprint - list of the fingerprint for grouping this event"},{"ref":"Sentry.Event.html#culprit_from_stacktrace/1","title":"Sentry.Event.culprit_from_stacktrace/1","type":"function","doc":""},{"ref":"Sentry.Event.html#do_put_source_context/3","title":"Sentry.Event.do_put_source_context/3","type":"function","doc":""},{"ref":"Sentry.Event.html#stacktrace_to_frames/1","title":"Sentry.Event.stacktrace_to_frames/1","type":"function","doc":""},{"ref":"Sentry.Event.html#transform_exception/2","title":"Sentry.Event.transform_exception/2","type":"function","doc":"Transforms an Exception to a Sentry event. Options :stacktrace - a list of Exception.stacktrace() :extra - map of extra context :user - map of user context :tags - map of tags context :request - map of request context :breadcrumbs - list of breadcrumbs :level - error level :fingerprint - list of the fingerprint for grouping this event"},{"ref":"Sentry.Event.html#t:sentry_exception/0","title":"Sentry.Event.sentry_exception/0","type":"type","doc":""},{"ref":"Sentry.Event.html#t:t/0","title":"Sentry.Event.t/0","type":"type","doc":""},{"ref":"Sentry.EventFilter.html","title":"Sentry.EventFilter","type":"behaviour","doc":"This module defines a Behaviour for filtering Sentry events. There is one callback to implement. The first argument will be the exception reported, and the second is the source. Events from Sentry.Plug will have :plug as a source, Sentry.Phoenix.Endpoint will have :endpoint and events from Sentry.LoggerBackend will have :logger as the source. A custom source can also be specified by passing the event_source option to Sentry.capture_exception/2. As an example, if you wanted to exclude any ArithmeticError exceptions: defmodule MyApp.SentryEventFilter do @behaviour Sentry.EventFilter def exclude_exception?(%ArithmeticError{}, _source), do: true def exclude_exception?(_exception, _source), do: false end"},{"ref":"Sentry.EventFilter.html#c:exclude_exception?/2","title":"Sentry.EventFilter.exclude_exception?/2","type":"callback","doc":"Callback that returns whether an exception should be excluded from being reported"},{"ref":"Sentry.HTTPClient.html","title":"Sentry.HTTPClient","type":"behaviour","doc":"Specifies the API for using a custom HTTP Client. Clients must implement the send_event/1 function that receives the Event and sends it to the Sentry API. It may return anything. See Sentry.Client for Sentry.TestClient for example implementations."},{"ref":"Sentry.HTTPClient.html#c:send_event/2","title":"Sentry.HTTPClient.send_event/2","type":"callback","doc":""},{"ref":"Sentry.LoggerBackend.html","title":"Sentry.LoggerBackend","type":"module","doc":"This module makes use of Elixir 1.7&#39;s new Logger metadata to report crashed processes. It replaces the previous Sentry.Logger sytem. To include the backend in your application, the backend can be added in your application file: def start(_type, _opts) do children = [ supervisor(MyApp.Repo, []), supervisor(MyAppWeb.Endpoint, []) ] opts = [strategy: :one_for_one, name: MyApp.Supervisor] {:ok, _} = Logger.add_backend(Sentry.LoggerBackend) Supervisor.start_link(children, opts) end If you are on OTP 21+ and would like to configure the backend to include metadata from Logger.metadata/0 in reported events, it can be enabled: {:ok, _} = Logger.add_backend(Sentry.LoggerBackend) Logger.configure_backend(Sentry.LoggerBackend, include_logger_metadata: true) It is important to be aware of whether this will include sensitive information in Sentry events before enabling it. Options The supported options are: :include_logger_metadata - Enabling this option will read any key/value pairs with with binary, atom or number values from Logger.metadata/0 and include that dictionary under the :logger_metadata key in an event&#39;s :extra metadata. This option defaults to false. :ignore_plug - Enabling this option will ignore any events that appear to be from a Plug process crashing. This is to prevent duplicate errors being reported to Sentry alongside Sentry.Plug."},{"ref":"Sentry.LoggerBackend.html#code_change/3","title":"Sentry.LoggerBackend.code_change/3","type":"function","doc":"Callback implementation for c::gen_event.code_change/3."},{"ref":"Sentry.LoggerBackend.html#handle_call/2","title":"Sentry.LoggerBackend.handle_call/2","type":"function","doc":"Callback implementation for c::gen_event.handle_call/2."},{"ref":"Sentry.LoggerBackend.html#handle_event/2","title":"Sentry.LoggerBackend.handle_event/2","type":"function","doc":"Callback implementation for c::gen_event.handle_event/2."},{"ref":"Sentry.LoggerBackend.html#handle_info/2","title":"Sentry.LoggerBackend.handle_info/2","type":"function","doc":"Callback implementation for c::gen_event.handle_info/2."},{"ref":"Sentry.LoggerBackend.html#init/1","title":"Sentry.LoggerBackend.init/1","type":"function","doc":"Callback implementation for c::gen_event.init/1."},{"ref":"Sentry.LoggerBackend.html#terminate/2","title":"Sentry.LoggerBackend.terminate/2","type":"function","doc":"Callback implementation for c::gen_event.terminate/2."},{"ref":"Sentry.Phoenix.Endpoint.html","title":"Sentry.Phoenix.Endpoint","type":"module","doc":"Provides basic functionality to handle errors in a Phoenix Endpoint. Errors occurring within a Phoenix request before it reaches the Router will not be captured by Sentry.Plug due to the internal functionality of Phoenix. It is recommended to include Sentry.Phoenix.Endpoint in your Phoenix app if you would like to receive errors occurring in the previously mentioned circumstances. For more information, see https://github.com/getsentry/sentry-elixir/issues/229 and https://github.com/phoenixframework/phoenix/issues/2791. Usage Add the following to your endpoint.ex, below use Phoenix.Endpoint, otp_app: :my_app use Sentry.Phoenix.Endpoint"},{"ref":"Sentry.Plug.html","title":"Sentry.Plug","type":"module","doc":"Provides basic functionality to handle Plug.ErrorHandler Usage Add the following to your router.ex: use Plug.ErrorHandler use Sentry.Plug Note that using Sentry.Plug will override default behaviour of Plug.ErrorHandler - it will no longer write &quot;Something went wrong&quot; as a response. If you want to retain this behaviour, or in general to add custom logic on top of sending event to sentry, you can do it like this: defp handle_errors(conn, %{kind: _kind, reason: _reason, stack: _stack} = error) do super(conn, error) send_resp(conn, conn.status, &quot;Something went wrong&quot;) end Sending Post Body Params In order to send post body parameters you should first scrub them of sensitive information. By default, they will be scrubbed with Sentry.Plug.default_body_scrubber/1. It can be overridden by passing the body_scrubber option, which accepts a Plug.Conn and returns a map to send. Setting :body_scrubber to nil will not send any data back. If you would like to make use of Sentry&#39;s default scrubber behavior in a custom scrubber, it can be called directly. An example configuration may look like the following: def scrub_params(conn) do # Makes use of the default body_scrubber to avoid sending password # and credit card information in plain text. To also prevent sending # our sensitive &quot;my_secret_field&quot; and &quot;other_sensitive_data&quot; fields, # we simply drop those keys. Sentry.Plug.default_body_scrubber(conn) |&gt; Map.drop([&quot;my_secret_field&quot;, &quot;other_sensitive_data&quot;]) end Then pass it into Sentry.Plug: use Sentry.Plug, body_scrubber: &amp;scrub_params/1 You can also pass it in as a {module, fun} like so: use Sentry.Plug, body_scrubber: {MyModule, :scrub_params} Please Note: If you are sending large files you will want to scrub them out. Headers Scrubber By default Sentry will scrub Authorization and Authentication headers from all requests before sending them. It can be configured similarly to the body params scrubber, but is configured with the :header_scrubber key. def scrub_headers(conn) do # default is: Sentry.Plug.default_header_scrubber(conn) # # We do not want to include Content-Type or User-Agent in reported # headers, so we drop them. Enum.into(conn.req_headers, %{}) |&gt; Map.drop([&quot;content-type&quot;, &quot;user-agent&quot;]) end Then pass it into Sentry.Plug: use Sentry.Plug, header_scrubber: &amp;scrub_headers/1 It can also be passed in as a {module, fun} like so: use Sentry.Plug, header_scrubber: {MyModule, :scrub_headers} Cookie Scrubber By default Sentry will scrub all cookies before sending events. It can be configured similarly to the headers scrubber, but is configured with the :cookie_scrubber key. To configure scrubbing, we can set all configuration keys: use Sentry.Plug, header_scrubber: &amp;scrub_headers/1, body_scrubber: &amp;scrub_params/1, cookie_scrubber: &amp;scrub_cookies/1 Including Request Identifiers If you&#39;re using Phoenix, Plug.RequestId, or another method to set a request ID response header, and would like to include that information with errors reported by Sentry.Plug, the :request_id_header option allows you to set which header key Sentry should check. It will default to &quot;x-request-id&quot;, which Plug.RequestId (and therefore Phoenix) also default to. use Sentry.Plug, request_id_header: &quot;application-request-id&quot;"},{"ref":"Sentry.Plug.html#build_request_interface_data/2","title":"Sentry.Plug.build_request_interface_data/2","type":"function","doc":""},{"ref":"Sentry.Plug.html#default_body_scrubber/1","title":"Sentry.Plug.default_body_scrubber/1","type":"function","doc":""},{"ref":"Sentry.Plug.html#default_cookie_scrubber/1","title":"Sentry.Plug.default_cookie_scrubber/1","type":"function","doc":""},{"ref":"Sentry.Plug.html#default_header_scrubber/1","title":"Sentry.Plug.default_header_scrubber/1","type":"function","doc":""},{"ref":"Sentry.Sources.html","title":"Sentry.Sources","type":"module","doc":"This module is responsible for providing functionality that stores the text of source files during compilation for displaying the source code that caused an exception. Configuration There is configuration required to set up this functionality. The options include :enable_source_code_context, :root_source_code_path, :context_lines, :source_code_exclude_patterns, and :source_code_path_pattern. :enable_source_code_context - when true, enables reporting source code alongside exceptions. :root_source_code_path - The path from which to start recursively reading files from. Should usually be set to File.cwd!(). :context_lines - The number of lines of source code before and after the line that caused the exception to be included. Defaults to 3. :source_code_exclude_patterns - a list of Regex expressions used to exclude file paths that should not be stored or referenced when reporting exceptions. Defaults to [~r&quot;/_build/&quot;, ~r&quot;/deps/&quot;, ~r&quot;/priv/&quot;]. :source_code_path_pattern - a glob that is expanded to select files from the :root_source_code_path. Defaults to &quot;**/*.ex&quot;. An example configuration: config :sentry, dsn: &quot;https://public:secret@app.getsentry.com/1&quot;, enable_source_code_context: true, root_source_code_path: File.cwd!(), context_lines: 5 Source code storage The file contents are saved when Sentry is compiled, which can cause some complications. If a file is changed, and Sentry is not recompiled, it will still report old source code. The best way to ensure source code is up to date is to recompile Sentry itself via mix deps.compile sentry --force. It&#39;s possible to create a Mix Task alias in mix.exs to do this. The example below would allow one to run mix.sentry_recompile which will force recompilation of Sentry so it has the newest source and then compile the project: defp aliases do [sentry_recompile: [&quot;compile&quot;, &quot;deps.compile sentry --force&quot;]] end This is an important to note especially when building for production. If your build or deployment system caches prior builds, it may not recompile Sentry and could cause issues with reported source code being out of date. Due to Sentry reading the file system and defaulting to a recursive search of directories, it is important to check your configuration and compilation environment to avoid a folder recursion issue. Problems may be seen when deploying to the root folder, so it is best to follow the practice of compiling your application in its own folder. Modifying the source_code_path_pattern configuration option from its default is also an avenue to avoid compile problems."},{"ref":"Sentry.Sources.html#get_source_context/3","title":"Sentry.Sources.get_source_context/3","type":"function","doc":"Given the source code map, a filename and a line number, this method retrieves the source code context. When reporting source code context to the Sentry API, it expects three separate values. They are the source code for the specific line the error occurred on, the list of the source code for the lines preceding, and the list of the source code for the lines following. The number of lines in the lists depends on what is configured in :context_lines. The number configured is how many lines to get on each side of the line that caused the error. If it is configured to be 3, the method will attempt to get the 3 lines preceding, the 3 lines following, and the line that the error occurred on, for a possible maximum of 7 lines. The three values are returned in a three element tuple as {preceding_source_code_list, source_code_from_error_line, following_source_code_list}."},{"ref":"Sentry.Sources.html#load_files/0","title":"Sentry.Sources.load_files/0","type":"function","doc":""},{"ref":"Sentry.Sources.html#t:file_map/0","title":"Sentry.Sources.file_map/0","type":"type","doc":""},{"ref":"Sentry.Sources.html#t:source_map/0","title":"Sentry.Sources.source_map/0","type":"type","doc":""},{"ref":"Sentry.Util.html","title":"Sentry.Util","type":"module","doc":"Provides basic utility functions."},{"ref":"Sentry.Util.html#iso8601_timestamp/0","title":"Sentry.Util.iso8601_timestamp/0","type":"function","doc":"Generates a iso8601_timestamp without microseconds and timezone"},{"ref":"Sentry.Util.html#mix_deps/0","title":"Sentry.Util.mix_deps/0","type":"function","doc":""},{"ref":"Sentry.Util.html#mix_deps_versions/1","title":"Sentry.Util.mix_deps_versions/1","type":"function","doc":""},{"ref":"Sentry.Util.html#unix_timestamp/0","title":"Sentry.Util.unix_timestamp/0","type":"function","doc":"Generates a unix timestamp"},{"ref":"Sentry.Util.html#uuid4_hex/0","title":"Sentry.Util.uuid4_hex/0","type":"function","doc":"Per http://www.ietf.org/rfc/rfc4122.txt"},{"ref":"readme.html","title":"sentry","type":"extras","doc":"sentry The Official Sentry Client for Elixir which provides a simple API to capture exceptions, automatically handle Plug Exceptions and provides a backend for the Elixir Logger. Documentation"},{"ref":"readme.html#note-on-upgrading-from-sentry-6-x-to-7-x","title":"sentry - Note on upgrading from Sentry 6.x to 7.x","type":"extras","doc":"Elixir 1.7 and Erlang/OTP 21 significantly changed how errors are transmitted (See &quot;Erlang/OTP logger integration&quot; here). Sentry integrated heavily with Erlang&#39;s :error_logger module, but it is no longer the suggested path towards handling errors. Sentry 7.x requires Elixir 1.7 and Sentry 6.x will be maintained for applications running prior versions. Documentation for Sentry 6.x can be found here. If you would like to upgrade a project to use Sentry 7.x, see here."},{"ref":"readme.html#installation","title":"sentry - Installation","type":"extras","doc":"To use Sentry with your projects, edit your mix.exs file and add it as a dependency. Sentry does not install a JSON library itself, and requires users to have one available. Sentry will default to trying to use Jason for JSON operations, but can be configured to use other ones. defp deps do [ # ... {:sentry, &quot;~&gt; 7.0&quot;}, {:jason, &quot;~&gt; 1.1&quot;}, ] end Setup with Plug or Phoenix In your Plug.Router or Phoenix.Router, add the following lines: use Plug.ErrorHandler use Sentry.Plug If you are using Phoenix, you can also include Sentry.Phoenix.Endpoint in your Endpoint. This module captures errors occurring in the Phoenix pipeline before the request reaches the Router: use Phoenix.Endpoint, otp_app: :my_app use Sentry.Phoenix.Endpoint More information on why this may be necessary can be found here: https://github.com/getsentry/sentry-elixir/issues/229 and https://github.com/phoenixframework/phoenix/issues/2791 Capture Crashed Process Exceptions This library comes with an extension to capture all error messages that the Plug handler might not. This is based on Logger.Backend. To set this up, add {:ok, _} = Logger.add_backend(Sentry.LoggerBackend) to your application&#39;s start function. Example: def start(_type, _opts) do children = [ supervisor(MyApp.Repo, []), supervisor(MyAppWeb.Endpoint, []) ] opts = [strategy: :one_for_one, name: MyApp.Supervisor] {:ok, _} = Logger.add_backend(Sentry.LoggerBackend) Supervisor.start_link(children, opts) end The backend can also be configured to capture Logger metadata, which is detailed here. Capture Arbitrary Exceptions Sometimes you want to capture specific exceptions. To do so, use Sentry.capture_exception/2. try do ThisWillError.really() rescue my_exception -&gt; Sentry.capture_exception(my_exception, [stacktrace: __STACKTRACE__, extra: %{extra: information}]) end Capture Non-Exception Events Sometimes you want to capture messages that are not Exceptions. Sentry.capture_message(&quot;custom_event_name&quot;, extra: %{extra: information}) For optional settings check the docs."},{"ref":"readme.html#configuration","title":"sentry - Configuration","type":"extras","doc":"KeyRequiredDefaultNotes dsnTruen/a environment_nameFalse:dev included_environmentsFalse[:test, :dev, :prod]If you need non-standard mix env names you need to include it here tagsFalse%{} releaseFalseNone server_nameFalseNone clientFalseSentry.ClientIf you need different functionality for the HTTP client, you can define your own module that implements the Sentry.HTTPClient behaviour and set client to that module hackney_optsFalse[pool: :sentry_pool] hackney_pool_max_connectionsFalse50 hackney_pool_timeoutFalse5000 before_send_eventFalse after_send_eventFalse sample_rateFalse1.0 in_app_module_whitelistFalse[] report_depsFalseTrueWill attempt to load Mix dependencies at compile time to report alongside events enable_source_code_contextFalseFalse root_source_code_pathRequired if enable_source_code_context is enabledShould generally be set to File.cwd!() context_linesFalse3 source_code_exclude_patternsFalse[~r&quot;/_build/&quot;, ~r&quot;/deps/&quot;, ~r&quot;/priv/&quot;] source_code_path_patternFalse&quot;**/*.ex&quot; filterFalseModule where the filter rules are defined (see Filtering Exceptions) json_libraryFalseJason log_levelFalse:warnThis sets the log level used when Sentry fails to send an event due to an invalid event or API error An example production config might look like this: config :sentry, dsn: &quot;https://public_key@app.getsentry.com/1&quot;, environment_name: :prod, included_environments: [:prod], enable_source_code_context: true, root_source_code_path: File.cwd!(), tags: %{ env: &quot;production&quot; }, hackney_opts: [pool: :my_pool], in_app_module_whitelist: [MyApp] The environment_name and included_environments work together to determine if and when Sentry should record exceptions. The environment_name is the name of the current environment. In the example above, we have explicitly set the environment to :prod which works well if you are inside an environment specific configuration like config/prod.exs. Alternatively, you could use Mix.env in your general configuration file: config :sentry, dsn: &quot;https://public_key@app.getsentry.com/1&quot;, included_environments: [:prod], environment_name: Mix.env You can even rely on more custom determinations of the environment name. It&#39;s not uncommon for most applications to have a &quot;staging&quot; environment. In order to handle this without adding an additional Mix environment, you can set an environment variable that determines the release level. config :sentry, dsn: &quot;https://public_key@app.getsentry.com/1&quot;, included_environments: ~w(production staging), environment_name: System.get_env(&quot;RELEASE_LEVEL&quot;) || &quot;development&quot; In this example, we are getting the environment name from the RELEASE_LEVEL environment variable. If that variable does not exist, we default to &quot;development&quot;. Now, on our servers, we can set the environment variable appropriately. On our local development machines, exceptions will never be sent, because the default value is not in the list of included_environments. Sentry uses the hackney HTTP client for HTTP requests. Sentry starts its own hackney pool named :sentry_pool with a default connection pool of 50, and a connection timeout of 5000 milliseconds. The pool can be configured with the hackney_pool_max_connections and hackney_pool_timeout configuration keys. If you need to set other hackney configurations for things like a proxy, using your own pool or response timeouts, the hackney_opts configuration is passed directly to hackney for each request. Context and Breadcrumbs Sentry has multiple options for including contextual information. They are organized into &quot;Tags&quot;, &quot;User&quot;, and &quot;Extra&quot;, and Sentry&#39;s documentation on them is here. Breadcrumbs are a similar concept and Sentry&#39;s documentation covers them here. In Elixir this can be complicated due to processes being isolated from one another. Tags context can be set globally through configuration, and all contexts can be set within a process, and on individual events. If an event is sent within a process that has some context configured it will include that context in the event. Examples of each are below, and for more information see the documentation of Sentry.Context. # Global Tags context via configuration: config :sentry, tags: %{my_app_version: &quot;14.30.10&quot;} # ... # Process-based Context Sentry.Context.set_extra_context(%{day_of_week: &quot;Friday&quot;}) Sentry.Context.set_user_context(%{id: 24, username: &quot;user_username&quot;, has_subscription: true}) Sentry.Context.set_tags_context(%{locale: &quot;en-us&quot;}) Sentry.Context.add_breadcrumb(%{category: &quot;web.request&quot;}) # Event-based Context Sentry.capture_exception(exception, [tags: %{locale: &quot;en-us&quot;, }, user: %{id: 34}, extra: %{day_of_week: &quot;Friday&quot;}, breadcrumbs: [%{timestamp: 1461185753845, category: &quot;web.request&quot;}]] Fingerprinting By default, Sentry aggregates reported events according to the attributes of the event, but users may need to override this functionality via fingerprinting. To achieve that in Sentry Elixir, one can use the before_send_event configuration callback. If there are certain types of errors you would like to have grouped differently, they can be matched on in the callback, and have the fingerprint attribute changed before the event is sent. An example configuration and implementation could look like: # lib/sentry.ex defmodule MyApp.Sentry def before_send(%{exception: [%{type: DBConnection.ConnectionError}]} = event) do %{event | fingerprint: [&quot;ecto&quot;, &quot;db_connection&quot;, &quot;timeout&quot;]} end def before_send(event) do event end end # config.exs config :sentry, before_send_event: {MyApp.Sentry, :before_send}, # ... Reporting Exceptions with Source Code Sentry&#39;s server supports showing the source code that caused an error, but depending on deployment, the source code for an application is not guaranteed to be available while it is running. To work around this, the Sentry library reads and stores the source code at compile time. This has some unfortunate implications. If a file is changed, and Sentry is not recompiled, it will still report old source code. The best way to ensure source code is up to date is to recompile Sentry itself via mix deps.compile sentry --force. It&#39;s possible to create a Mix Task alias in mix.exs to do this. The example below allows one to run mix sentry_recompile which will compile any uncompiled or changed parts of the application, and then force recompilation of Sentry so it has the newest source: # mix.exs defp aliases do [sentry_recompile: [&quot;compile&quot;, &quot;deps.compile sentry --force&quot;]] end For more documentation, see Sentry.Sources."},{"ref":"readme.html#testing-your-configuration","title":"sentry - Testing Your Configuration","type":"extras","doc":"To ensure you&#39;ve set up your configuration correctly we recommend running the included mix task. It can be tested on different Mix environments and will tell you if it is not currently configured to send events in that environment: $ MIX_ENV=dev mix sentry.send_test_event Client configuration: server: https://sentry.io/ public_key: public secret_key: secret included_environments: [:prod] current environment_name: :dev :dev is not in [:prod] so no test event will be sent $ MIX_ENV=prod mix sentry.send_test_event Client configuration: server: https://sentry.io/ public_key: public secret_key: secret included_environments: [:prod] current environment_name: :prod Sending test event!"},{"ref":"readme.html#testing-with-sentry","title":"sentry - Testing with Sentry","type":"extras","doc":"In some cases, users may want to test that certain actions in their application cause a report to be sent to Sentry. Sentry itself does this by using Bypass. It is important to note that when modifying the environment configuration the test case should not be run asynchronously. Not returning the environment configuration to its original state could also affect other tests depending on how the Sentry configuration interacts with them. Example: test &quot;add/2 does not raise but sends an event to Sentry when given bad input&quot; do bypass = Bypass.open() Bypass.expect(bypass, fn conn -&gt; {:ok, _body, conn} = Plug.Conn.read_body(conn) Plug.Conn.resp(conn, 200, ~s&lt;{&quot;id&quot;: &quot;340&quot;}&gt;) end) Application.put_env(:sentry, :dsn, &quot;http://public:secret@localhost:\#{bypass.port}/1&quot;) MyModule.add(1, &quot;a&quot;) end"},{"ref":"readme.html#license","title":"sentry - License","type":"extras","doc":"This project is Licensed under the MIT License."}]